Crate qualomat_schema
source ·Expand description
qualomat_schema
A Rust crate for reading data from the qual-o-mat-data repository, which is an open data archive for the german voting advice tool Wahl-O-Mat.
Usage
Clone the data repository:
git clone https://github.com/gockelhahn/qual-o-mat-data
Read the data for all elections:
let elections = Election::read_all_from_path("qual-o-mat-data")?;Code generation
The generated code was created from the Qual-O-Mat schema using typify and the code in qualomat_schema_gen.
Modules
- Loading data from json files.
Structs
- Answer
- Category
- Comment
- All the data available for a single election
- Path to a specific election in the dataset. Election
- Overview and info of an election
- Opinion
- Party
- Statement